==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetADLSGen2FolderDataSetResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * An ADLS Gen 2 folder data set.
 * @property dataSetId Unique id for identifying a data set resource
 * @property fileSystem File system to which the folder belongs.
 * @property folderPath Folder path within the file system.
 * @property id The resource id of the azure resource
 * @property kind Kind of data set.
 * Expected value is 'AdlsGen2Folder'.
 * @property name Name of the azure resource
 * @property resourceGroup Resource group of storage account
 * @property storageAccountName Storage account name of the source data set
 * @property subscriptionId Subscription id of storage account
 * @property systemData System Data of the Azure resource.
 * @property type Type of the azure resource
 */
public data class GetADLSGen2FolderDataSetResult(
    public val dataSetId: String,
    public val fileSystem: String,
    public val folderPath: String,
    public val id: String,
    public val kind: String,
    public val name: String,
    public val resourceGroup: String,
    public val storageAccountName: String,
    public val subscriptionId: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetADLSGen2FolderDataSetResult):
            GetADLSGen2FolderDataSetResult = GetADLSGen2FolderDataSetResult(
            dataSetId = javaType.dataSetId(),
            fileSystem = javaType.fileSystem(),
            folderPath = javaType.folderPath(),
            id = javaType.id(),
            kind = javaType.kind(),
            name = javaType.name(),
            resourceGroup = javaType.resourceGroup(),
            storageAccountName = javaType.storageAccountName(),
            subscriptionId = javaType.subscriptionId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetADLSGen2FolderDataSetResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * An ADLS Gen 2 folder data set.
 * @property dataSetId Unique id for identifying a data set resource
 * @property fileSystem File system to which the folder belongs.
 * @property folderPath Folder path within the file system.
 * @property id The resource id of the azure resource
 * @property kind Kind of data set.
 * Expected value is 'AdlsGen2Folder'.
 * @property name Name of the azure resource
 * @property resourceGroup Resource group of storage account
 * @property storageAccountName Storage account name of the source data set
 * @property subscriptionId Subscription id of storage account
 * @property systemData System Data of the Azure resource.
 * @property type Type of the azure resource
 */
public data class GetADLSGen2FolderDataSetResult(
    public val dataSetId: String,
    public val fileSystem: String,
    public val folderPath: String,
    public val id: String,
    public val kind: String,
    public val name: String,
    public val resourceGroup: String,
    public val storageAccountName: String,
    public val subscriptionId: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetADLSGen2FolderDataSetResult): GetADLSGen2FolderDataSetResult = GetADLSGen2FolderDataSetResult(
            dataSetId = javaType.dataSetId(),
            fileSystem = javaType.fileSystem(),
            folderPath = javaType.folderPath(),
            id = javaType.id(),
            kind = javaType.kind(),
            name = javaType.name(),
            resourceGroup = javaType.resourceGroup(),
            storageAccountName = javaType.storageAccountName(),
            subscriptionId = javaType.subscriptionId(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
